#define UNICODE_CATEGORY_1_CONTROL                                 0x01000000
#define UNICODE_CATEGORY_1_DIACRITIC                               0x02000000
#define     UNICODE_CATEGORY_2_ANNOTATION                          0x00010000
#define     UNICODE_CATEGORY_2_CANTILLATION                        0x00020000
#define     UNICODE_CATEGORY_2_DOUBLE                              0x00030000
#define     UNICODE_CATEGORY_2_ENCLOSING                           0x00040000
#define     UNICODE_CATEGORY_2_HISTORIC                            0x00050000
#define     UNICODE_CATEGORY_2_LENGTH                              0x00060000
#define     UNICODE_CATEGORY_2_LETTER                              0x00070000
#define         UNICODE_CATEGORY_3_SUPERSCRIPT                     0x00000100
#define     UNICODE_CATEGORY_2_NASALIZATION                        0x00080000
#define     UNICODE_CATEGORY_2_NUMBER                              0x00090000
/* #define         UNICODE_CATEGORY_3_SUPERSCRIPT                  0x00000100 */
#define     UNICODE_CATEGORY_2_OVERSTRUCK                          0x000a0000
#define     UNICODE_CATEGORY_2_SPACING                             0x000b0000
#define         UNICODE_CATEGORY_3_NUMERAL                         0x00000200
#define     UNICODE_CATEGORY_2_TONE                                0x000c0000
#define     UNICODE_CATEGORY_2_VISARGA                             0x000d0000
#define UNICODE_CATEGORY_1_FORMAT                                  0x03000000
/* #define     UNICODE_CATEGORY_2_ANNOTATION                       0x00010000 */
#define     UNICODE_CATEGORY_2_BIDI                                0x000e0000
#define     UNICODE_CATEGORY_2_JOINING                             0x000f0000
#define     UNICODE_CATEGORY_2_KASHIDA                             0x00100000
#define     UNICODE_CATEGORY_2_LINEBREAK                           0x00110000
#define     UNICODE_CATEGORY_2_SUBTENDING                          0x00120000
#define     UNICODE_CATEGORY_2_TAG                                 0x00130000
#define     UNICODE_CATEGORY_2_VARIATION_SELECTOR                  0x00140000
#define UNICODE_CATEGORY_1_HIEROGLYPH                              0x04000000
#define     UNICODE_CATEGORY_2_AGRICULTURE_CRAFT_PROFESSION        0x00150000
#define     UNICODE_CATEGORY_2_AMPHIBIOUS_ANIMAL_REPTILE           0x00160000
#define     UNICODE_CATEGORY_2_ANTHROPOMORPHIC_DEITY               0x00170000
#define     UNICODE_CATEGORY_2_BIRD                                0x00180000
#define     UNICODE_CATEGORY_2_BUILDING_PART_OF_BUILDING           0x00190000
#define     UNICODE_CATEGORY_2_CROWN_DRESS_STAFF                   0x001a0000
#define     UNICODE_CATEGORY_2_DOMESTIC_AND_FUNERARY_FURNITURE     0x001b0000
#define     UNICODE_CATEGORY_2_FISH_PART_OF_FISH                   0x001c0000
#define     UNICODE_CATEGORY_2_INVERTABRATA_LESSER_ANIMAL          0x001d0000
#define     UNICODE_CATEGORY_2_LOAF_CAKE                           0x001e0000
#define     UNICODE_CATEGORY_2_MAMMAL                              0x001f0000
#define     UNICODE_CATEGORY_2_MAN_OCCUPATION                      0x00200000
#define     UNICODE_CATEGORY_2_NOME_OF_LOWER_EGYPT                 0x00210000
#define     UNICODE_CATEGORY_2_NOME_OF_UPPER_EGYPT                 0x00220000
#define     UNICODE_CATEGORY_2_PART_OF_BIRD                        0x00230000
#define     UNICODE_CATEGORY_2_PART_OF_MAMMAL                      0x00240000
#define     UNICODE_CATEGORY_2_PART_OF_THE_HUMAN_BODY              0x00250000
#define     UNICODE_CATEGORY_2_ROPE_FIBER_BASKET_BAG               0x00260000
#define     UNICODE_CATEGORY_2_SHIP_PART_OF_SHIP                   0x00270000
#define     UNICODE_CATEGORY_2_SKY_EARTH_WATER                     0x00280000
#define     UNICODE_CATEGORY_2_TEMPLE_FURNITURE_SACRED_EMBLEM      0x00290000
#define     UNICODE_CATEGORY_2_TREE_PLANT                          0x002a0000
#define     UNICODE_CATEGORY_2_VESSEL_OF_STONE_OR_EARTHENWARE      0x002b0000
#define     UNICODE_CATEGORY_2_WARFARE_HUNTING_BUTCHERY            0x002c0000
#define     UNICODE_CATEGORY_2_WOMAN_OCCUPATION                    0x002d0000
#define     UNICODE_CATEGORY_2_WRITING_GAME_MUSIC                  0x002e0000
#define UNICODE_CATEGORY_1_IDEOGRAM                                0x05000000
#define     UNICODE_CATEGORY_2_CEREALS_AND_PLANTS                  0x002f0000
#define     UNICODE_CATEGORY_2_EXTRACTS                            0x00300000
#define     UNICODE_CATEGORY_2_METALS                              0x00310000
#define     UNICODE_CATEGORY_2_OTHER_MATERIALS                     0x00320000
#define     UNICODE_CATEGORY_2_PEOPLE_AND_ANIMALS                  0x00330000
#define     UNICODE_CATEGORY_2_VESSELS                             0x00340000
#define UNICODE_CATEGORY_1_IDEOGRAPH                               0x06000000
#define     UNICODE_CATEGORY_2_MODIFIER                            0x00350000
#define         UNICODE_CATEGORY_3_REPETITION                      0x00000300
#define             UNICODE_CATEGORY_4_VERTICAL                    0x00000001
/* #define         UNICODE_CATEGORY_3_SUPERSCRIPT                  0x00000100 */
#define     UNICODE_CATEGORY_2_RADICAL                             0x00360000
#define         UNICODE_CATEGORY_3_CJK                             0x00000400
#define             UNICODE_CATEGORY_4_KANGXI                      0x00000002
#define     UNICODE_CATEGORY_2_STROKE                              0x00370000
/* #define         UNICODE_CATEGORY_3_CJK                          0x00000400 */
#define UNICODE_CATEGORY_1_LETTER                                  0x07000000
#define     UNICODE_CATEGORY_2_CONSONANT                           0x00380000
#define         UNICODE_CATEGORY_3_DEPENDENT                       0x00000500
#define             UNICODE_CATEGORY_4_SUBJOINED                   0x00000003
#define         UNICODE_CATEGORY_3_DIGRAPH                         0x00000600
#define         UNICODE_CATEGORY_3_FINAL                           0x00000700
#define         UNICODE_CATEGORY_3_HISTORIC                        0x00000800
#define         UNICODE_CATEGORY_3_INITIAL                         0x00000900
#define             UNICODE_CATEGORY_4_FILLER                      0x00000004
#define     UNICODE_CATEGORY_2_CRYPTOGRAMMIC                       0x00390000
#define     UNICODE_CATEGORY_2_DIGRAPH                             0x003a0000
#define     UNICODE_CATEGORY_2_FILLER                              0x003b0000
#define     UNICODE_CATEGORY_2_FRAGMENT                            0x003c0000
#define     UNICODE_CATEGORY_2_HEAD_MARK                           0x003d0000
#define         UNICODE_CATEGORY_3_SUBJOINED                       0x00000a00
/* #define     UNICODE_CATEGORY_2_HISTORIC                         0x00050000 */
#define     UNICODE_CATEGORY_2_LIGATURE                            0x003e0000
/* #define     UNICODE_CATEGORY_2_MODIFIER                         0x00350000 */
#define         UNICODE_CATEGORY_3_NASALIZATION                    0x00000b00
/* #define         UNICODE_CATEGORY_3_REPETITION                   0x00000300 */
#define         UNICODE_CATEGORY_3_SUBSCRIPT                       0x00000c00
/* #define         UNICODE_CATEGORY_3_SUPERSCRIPT                  0x00000100 */
#define     UNICODE_CATEGORY_2_PHONETIC                            0x003f0000
#define         UNICODE_CATEGORY_3_IPA                             0x00000d00
#define         UNICODE_CATEGORY_3_SINOLOGY                        0x00000e00
#define         UNICODE_CATEGORY_3_UPA                             0x00000f00
/* #define     UNICODE_CATEGORY_2_TONE                             0x000c0000 */
#define     UNICODE_CATEGORY_2_VARIANT                             0x00400000
#define     UNICODE_CATEGORY_2_VOWEL                               0x00410000
/* #define         UNICODE_CATEGORY_3_DEPENDENT                    0x00000500 */
#define             UNICODE_CATEGORY_4_LENGTH_MARK                 0x00000005
#define             UNICODE_CATEGORY_4_TWO_PART                    0x00000006
#define         UNICODE_CATEGORY_3_INDEPENDENT                     0x00001000
#define         UNICODE_CATEGORY_3_INHERENT                        0x00001100
#define         UNICODE_CATEGORY_3_LENGTH_MARK                     0x00001200
#define         UNICODE_CATEGORY_3_MEDIAL                          0x00001300
/* #define             UNICODE_CATEGORY_4_FILLER                   0x00000004 */
#define UNICODE_CATEGORY_1_LOGOGRAPH                               0x08000000
#define UNICODE_CATEGORY_1_MARK                                    0x09000000
#define     UNICODE_CATEGORY_2_POINT                               0x00420000
/* #define     UNICODE_CATEGORY_2_TONE                             0x000c0000 */
/* #define     UNICODE_CATEGORY_2_VOWEL                            0x00410000 */
#define         UNICODE_CATEGORY_3_POINT                           0x00001400
#define             UNICODE_CATEGORY_4_SPACING                     0x00000007
#define UNICODE_CATEGORY_1_NUMBER                                  0x0a000000
#define     UNICODE_CATEGORY_2_ACCOUNTING                          0x00430000
#define     UNICODE_CATEGORY_2_ACROPHONIC                          0x00440000
#define     UNICODE_CATEGORY_2_DIGIT                               0x00450000
/* #define         UNICODE_CATEGORY_3_SUBSCRIPT                    0x00000c00 */
/* #define         UNICODE_CATEGORY_3_SUPERSCRIPT                  0x00000100 */
#define     UNICODE_CATEGORY_2_FRACTION                            0x00460000
/* #define     UNICODE_CATEGORY_2_LETTER                           0x00070000 */
#define         UNICODE_CATEGORY_3_ROMAN                           0x00001500
#define             UNICODE_CATEGORY_4_HISTORIC                    0x00000008
#define UNICODE_CATEGORY_1_PUNCTUATION                             0x0b000000
/* #define     UNICODE_CATEGORY_2_ANNOTATION                       0x00010000 */
#define     UNICODE_CATEGORY_2_BRACKET                             0x00470000
/* #define         UNICODE_CATEGORY_3_CJK                          0x00000400 */
#define             UNICODE_CATEGORY_4_CORNER                      0x00000009
#define         UNICODE_CATEGORY_3_FRAGMENT                        0x00001600
#define         UNICODE_CATEGORY_3_HORIZONTAL                      0x00001700
#define         UNICODE_CATEGORY_3_MATH                            0x00001800
/* #define         UNICODE_CATEGORY_3_SUBSCRIPT                    0x00000c00 */
/* #define         UNICODE_CATEGORY_3_SUPERSCRIPT                  0x00000100 */
#define         UNICODE_CATEGORY_3_VERTICAL                        0x00001900
#define     UNICODE_CATEGORY_2_DASH                                0x00480000
/* #define         UNICODE_CATEGORY_3_VERTICAL                     0x00001900 */
#define     UNICODE_CATEGORY_2_DICTIONARY                          0x00490000
#define     UNICODE_CATEGORY_2_EDITORIAL                           0x004a0000
#define         UNICODE_CATEGORY_3_BIBLICAL                        0x00001a00
/* #define     UNICODE_CATEGORY_2_HISTORIC                         0x00050000 */
#define     UNICODE_CATEGORY_2_QUOTATION                           0x004b0000
#define     UNICODE_CATEGORY_2_SPACE                               0x004c0000
#define     UNICODE_CATEGORY_2_VERTICAL                            0x004d0000
#define UNICODE_CATEGORY_1_SIGN                                    0x0c000000
#define UNICODE_CATEGORY_1_SYLLABLE                                0x0d000000
/* #define     UNICODE_CATEGORY_2_DIGRAPH                          0x003a0000 */
/* #define     UNICODE_CATEGORY_2_HISTORIC                         0x00050000 */
/* #define     UNICODE_CATEGORY_2_MODIFIER                         0x00350000 */
#define         UNICODE_CATEGORY_3_LENGTH                          0x00001b00
/* #define         UNICODE_CATEGORY_3_REPETITION                   0x00000300 */
/* #define             UNICODE_CATEGORY_4_VERTICAL                 0x00000001 */
/* #define     UNICODE_CATEGORY_2_RADICAL                          0x00360000 */
#define UNICODE_CATEGORY_1_SYMBOL                                  0x0e000000
#define     UNICODE_CATEGORY_2_ALCHEMICAL                          0x004e0000
#define         UNICODE_CATEGORY_3_APPARATUS                       0x00001c00
#define         UNICODE_CATEGORY_3_MEASURE                         0x00001d00
#define         UNICODE_CATEGORY_3_PROCESS                         0x00001e00
#define         UNICODE_CATEGORY_3_TIME                            0x00001f00
#define     UNICODE_CATEGORY_2_ANIMAL                              0x004f0000
#define         UNICODE_CATEGORY_3_FACE                            0x00002000
#define         UNICODE_CATEGORY_3_ZODIAC                          0x00002100
#define     UNICODE_CATEGORY_2_ARROW                               0x00500000
#define         UNICODE_CATEGORY_3_BLACK                           0x00002200
#define         UNICODE_CATEGORY_3_CROSSING                        0x00002300
#define             UNICODE_CATEGORY_4_KNOT_THEORY                 0x0000000a
#define         UNICODE_CATEGORY_3_DOUBLE                          0x00002400
/* #define         UNICODE_CATEGORY_3_FRAGMENT                     0x00001600 */
#define         UNICODE_CATEGORY_3_HARPOON                         0x00002500
#define         UNICODE_CATEGORY_3_LONG                            0x00002600
#define         UNICODE_CATEGORY_3_TAIL                            0x00002700
#define     UNICODE_CATEGORY_2_ASTROLOGICAL                        0x00510000
#define     UNICODE_CATEGORY_2_ASTRONOMICAL                        0x00520000
#define     UNICODE_CATEGORY_2_AUDIO_VIDEO                         0x00530000
#define     UNICODE_CATEGORY_2_BEVERAGE                            0x00540000
#define     UNICODE_CATEGORY_2_BODY_PART                           0x00550000
/* #define         UNICODE_CATEGORY_3_FACE                         0x00002000 */
#define     UNICODE_CATEGORY_2_BRAILLE_PATTERN                     0x00560000
#define     UNICODE_CATEGORY_2_BROADCAST                           0x00570000
#define         UNICODE_CATEGORY_3_CLOSED_CAPTIONING               0x00002800
#define     UNICODE_CATEGORY_2_CALENDRICAL                         0x00580000
/* #define     UNICODE_CATEGORY_2_CANTILLATION                     0x00020000 */
#define     UNICODE_CATEGORY_2_CELEBRATION                         0x00590000
#define     UNICODE_CATEGORY_2_CLOCK_FACE                          0x005a0000
#define     UNICODE_CATEGORY_2_CLOTHING                            0x005b0000
#define     UNICODE_CATEGORY_2_COMIC_STYLE                         0x005c0000
#define     UNICODE_CATEGORY_2_COMMUNICATION                       0x005d0000
#define     UNICODE_CATEGORY_2_CULTURAL                            0x005e0000
#define     UNICODE_CATEGORY_2_CURRENCY                            0x005f0000
/* #define     UNICODE_CATEGORY_2_DICTIONARY                       0x00490000 */
#define     UNICODE_CATEGORY_2_DIGRAM                              0x00600000
#define         UNICODE_CATEGORY_3_YIJING                          0x00002900
#define     UNICODE_CATEGORY_2_DINGBAT                             0x00610000
#define         UNICODE_CATEGORY_3_ARROW                           0x00002a00
#define         UNICODE_CATEGORY_3_CROSS                           0x00002b00
#define         UNICODE_CATEGORY_3_HAND                            0x00002c00
#define             UNICODE_CATEGORY_4_POINTING                    0x0000000b
#define         UNICODE_CATEGORY_3_ORNAMENTAL_BRACKET              0x00002d00
#define         UNICODE_CATEGORY_3_PUNCTUATION_ORNAMENT            0x00002e00
#define         UNICODE_CATEGORY_3_STARLIKE                        0x00002f00
/* #define     UNICODE_CATEGORY_2_EDITORIAL                        0x004a0000 */
/* #define         UNICODE_CATEGORY_3_BIBLICAL                     0x00001a00 */
#define     UNICODE_CATEGORY_2_EMOTICON                            0x00620000
/* #define         UNICODE_CATEGORY_3_FACE                         0x00002000 */
#define             UNICODE_CATEGORY_4_CAT                         0x0000000c
#define         UNICODE_CATEGORY_3_GESTURE                         0x00003000
#define     UNICODE_CATEGORY_2_ENTERTAINMENT                       0x00630000
#define     UNICODE_CATEGORY_2_FAIRY_TALE                          0x00640000
#define     UNICODE_CATEGORY_2_FINANCE                             0x00650000
#define     UNICODE_CATEGORY_2_FOOD                                0x00660000
#define     UNICODE_CATEGORY_2_FRUIT                               0x00670000
#define     UNICODE_CATEGORY_2_GAME                                0x00680000
#define         UNICODE_CATEGORY_3_CHESS                           0x00003100
#define         UNICODE_CATEGORY_3_DICE                            0x00003200
#define         UNICODE_CATEGORY_3_DOMINO_TILE                     0x00003300
#define             UNICODE_CATEGORY_4_HORIZONTAL                  0x0000000d
/* #define             UNICODE_CATEGORY_4_VERTICAL                 0x00000001 */
#define         UNICODE_CATEGORY_3_DRAUGHTS_AND_CHECKERS           0x00003400
#define         UNICODE_CATEGORY_3_GO                              0x00003500
#define             UNICODE_CATEGORY_4_MARKER                      0x0000000e
#define         UNICODE_CATEGORY_3_JAPANESE_CHESS                  0x00003600
#define         UNICODE_CATEGORY_3_MAHJONG_TILE                    0x00003700
#define             UNICODE_CATEGORY_4_BAMBOO_SUIT                 0x0000000f
#define             UNICODE_CATEGORY_4_CHARACTER_SUIT              0x00000010
#define             UNICODE_CATEGORY_4_CIRCLE_SUIT                 0x00000011
#define             UNICODE_CATEGORY_4_DRAGON                      0x00000012
#define             UNICODE_CATEGORY_4_FLOWER                      0x00000013
#define             UNICODE_CATEGORY_4_PREVAILING_WIND             0x00000014
#define             UNICODE_CATEGORY_4_SEASON                      0x00000015
#define         UNICODE_CATEGORY_3_PLAYING_CARD                    0x00003800
#define     UNICODE_CATEGORY_2_GENDER                              0x00690000
#define     UNICODE_CATEGORY_2_GENEALOGICAL                        0x006a0000
#define     UNICODE_CATEGORY_2_GEOMETRIC                           0x006b0000
#define         UNICODE_CATEGORY_3_CIRCLE                          0x00003900
#define     UNICODE_CATEGORY_2_GLOBE                               0x006c0000
#define     UNICODE_CATEGORY_2_GRAPHIC                             0x006d0000
#define         UNICODE_CATEGORY_3_BLOCK                           0x00003a00
#define         UNICODE_CATEGORY_3_CONTROL_CODE                    0x00003b00
#define         UNICODE_CATEGORY_3_FORM                            0x00003c00
#define         UNICODE_CATEGORY_3_SHADE                           0x00003d00
#define         UNICODE_CATEGORY_3_SPACE                           0x00003e00
#define         UNICODE_CATEGORY_3_TERMINAL                        0x00003f00
/* #define     UNICODE_CATEGORY_2_HEAD_MARK                        0x003d0000 */
#define     UNICODE_CATEGORY_2_HEART                               0x006e0000
#define     UNICODE_CATEGORY_2_HEXAGRAM                            0x006f0000
/* #define         UNICODE_CATEGORY_3_YIJING                       0x00002900 */
#define     UNICODE_CATEGORY_2_IDEOGRAPH                           0x00700000
#define         UNICODE_CATEGORY_3_BRACKETED                       0x00004000
#define         UNICODE_CATEGORY_3_CIRCLED                         0x00004100
#define         UNICODE_CATEGORY_3_PARENTHESIZED                   0x00004200
#define         UNICODE_CATEGORY_3_SQUARED                         0x00004300
#define     UNICODE_CATEGORY_2_IDEOGRAPHIC_DESCRIPTION             0x00710000
#define     UNICODE_CATEGORY_2_LANDSCAPE                           0x00720000
/* #define     UNICODE_CATEGORY_2_LETTER                           0x00070000 */
/* #define         UNICODE_CATEGORY_3_BRACKETED                    0x00004000 */
/* #define         UNICODE_CATEGORY_3_CIRCLED                      0x00004100 */
#define             UNICODE_CATEGORY_4_ITALIC                      0x00000016
/* #define         UNICODE_CATEGORY_3_PARENTHESIZED                0x00004200 */
#define         UNICODE_CATEGORY_3_REGIONAL_INDICATOR              0x00004400
/* #define         UNICODE_CATEGORY_3_SQUARED                      0x00004300 */
#define             UNICODE_CATEGORY_4_ABBREVIATION                0x00000017
#define     UNICODE_CATEGORY_2_LETTERLIKE                          0x00730000
#define     UNICODE_CATEGORY_2_MAP                                 0x00740000
#define     UNICODE_CATEGORY_2_MATH                                0x00750000
#define         UNICODE_CATEGORY_3_ALPHANUMERIC                    0x00004500
#define             UNICODE_CATEGORY_4_BOLD                        0x00000018
#define             UNICODE_CATEGORY_4_BOLD_DIGIT                  0x00000019
#define             UNICODE_CATEGORY_4_BOLD_FRAKTUR                0x0000001a
#define             UNICODE_CATEGORY_4_BOLD_GREEK                  0x0000001b
#define             UNICODE_CATEGORY_4_BOLD_ITALIC                 0x0000001c
#define             UNICODE_CATEGORY_4_BOLD_ITALIC_GREEK           0x0000001d
#define             UNICODE_CATEGORY_4_BOLD_SCRIPT                 0x0000001e
#define             UNICODE_CATEGORY_4_DOUBLE_STRUCK               0x0000001f
#define             UNICODE_CATEGORY_4_DOUBLE_STRUCK_DIGIT         0x00000020
#define             UNICODE_CATEGORY_4_FRAKTUR                     0x00000021
#define             UNICODE_CATEGORY_4_INITIAL                     0x00000022
#define             UNICODE_CATEGORY_4_ISOLATED                    0x00000023
/* #define             UNICODE_CATEGORY_4_ITALIC                   0x00000016 */
#define             UNICODE_CATEGORY_4_ITALIC_GREEK                0x00000024
#define             UNICODE_CATEGORY_4_LARGE                       0x00000025
#define             UNICODE_CATEGORY_4_LOOPED                      0x00000026
#define             UNICODE_CATEGORY_4_MONOSPACE                   0x00000027
#define             UNICODE_CATEGORY_4_MONOSPACE_DIGIT             0x00000028
#define             UNICODE_CATEGORY_4_SANS_SERIF                  0x00000029
#define             UNICODE_CATEGORY_4_SANS_SERIF_BOLD             0x0000002a
#define             UNICODE_CATEGORY_4_SANS_SERIF_BOLD_DIGIT       0x0000002b
#define             UNICODE_CATEGORY_4_SANS_SERIF_BOLD_GREEK       0x0000002c
#define             UNICODE_CATEGORY_4_SANS_SERIF_BOLD_ITALIC      0x0000002d
#define             UNICODE_CATEGORY_4_SANS_SERIF_BOLD_ITALIC_GREEK 0x0000002e
#define             UNICODE_CATEGORY_4_SANS_SERIF_DIGIT            0x0000002f
#define             UNICODE_CATEGORY_4_SANS_SERIF_ITALIC           0x00000030
#define             UNICODE_CATEGORY_4_SCRIPT                      0x00000031
#define             UNICODE_CATEGORY_4_STRETCHED                   0x00000032
#define             UNICODE_CATEGORY_4_TAILED                      0x00000033
#define         UNICODE_CATEGORY_3_ANGLE                           0x00004600
#define         UNICODE_CATEGORY_3_CONSTANT                        0x00004700
#define         UNICODE_CATEGORY_3_EMPTY_SET                       0x00004800
#define         UNICODE_CATEGORY_3_ERROR_BAR                       0x00004900
#define         UNICODE_CATEGORY_3_FENCE                           0x00004a00
#define         UNICODE_CATEGORY_3_FORK                            0x00004b00
#define         UNICODE_CATEGORY_3_HEBREW                          0x00004c00
#define         UNICODE_CATEGORY_3_INTEGRAL                        0x00004d00
#define             UNICODE_CATEGORY_4_FRAGMENT                    0x00000034
#define         UNICODE_CATEGORY_3_OPERATOR                        0x00004e00
/* #define             UNICODE_CATEGORY_4_FRAGMENT                 0x00000034 */
/* #define             UNICODE_CATEGORY_4_LARGE                    0x00000025 */
#define             UNICODE_CATEGORY_4_MODAL_LOGIC                 0x00000035
#define         UNICODE_CATEGORY_3_RELATION                        0x00004f00
/* #define         UNICODE_CATEGORY_3_SUBSCRIPT                    0x00000c00 */
/* #define         UNICODE_CATEGORY_3_SUPERSCRIPT                  0x00000100 */
#define     UNICODE_CATEGORY_2_MEASURE                             0x00760000
#define     UNICODE_CATEGORY_2_MEDICAL                             0x00770000
#define     UNICODE_CATEGORY_2_METRICAL                            0x00780000
#define     UNICODE_CATEGORY_2_MICR                                0x00790000
#define     UNICODE_CATEGORY_2_MONOGRAM                            0x007a0000
/* #define         UNICODE_CATEGORY_3_YIJING                       0x00002900 */
#define     UNICODE_CATEGORY_2_MUSIC                               0x007b0000
#define         UNICODE_CATEGORY_3_ANCIENT_GREEK                   0x00005000
#define             UNICODE_CATEGORY_4_INSTRUMENTAL                0x00000036
#define             UNICODE_CATEGORY_4_VOCALIC                     0x00000037
#define         UNICODE_CATEGORY_3_BYZANTINE                       0x00005100
#define             UNICODE_CATEGORY_4_AFONA_OR_YPOSTASEIS         0x00000038
#define             UNICODE_CATEGORY_4_AGOGIKA                     0x00000039
#define             UNICODE_CATEGORY_4_ALLOIOSEIS                  0x0000003a
#define             UNICODE_CATEGORY_4_ARGIES                      0x0000003b
#define             UNICODE_CATEGORY_4_EKFONETIKA                  0x0000003c
#define             UNICODE_CATEGORY_4_FONITIKA                    0x0000003d
#define             UNICODE_CATEGORY_4_FTHORES                     0x0000003e
#define             UNICODE_CATEGORY_4_GRAMMATA                    0x0000003f
#define             UNICODE_CATEGORY_4_ICHIMATA_OR_MARTYRIKA       0x00000040
#define             UNICODE_CATEGORY_4_LEIMMATA_OR_SIOPES          0x00000041
#define             UNICODE_CATEGORY_4_MELODIMATA                  0x00000042
#define             UNICODE_CATEGORY_4_PROSODIES                   0x00000043
#define             UNICODE_CATEGORY_4_RYTHMIKA                    0x00000044
#define             UNICODE_CATEGORY_4_SPECIAL                     0x00000045
#define             UNICODE_CATEGORY_4_SYNAGMATA_OR_GORGOTITES     0x00000046
#define         UNICODE_CATEGORY_3_GREGORIAN                       0x00005200
#define         UNICODE_CATEGORY_3_MENSURAL                        0x00005300
#define             UNICODE_CATEGORY_4_PROLATION                   0x00000047
#define             UNICODE_CATEGORY_4_REST                        0x00000048
#define         UNICODE_CATEGORY_3_WESTERN                         0x00005400
#define             UNICODE_CATEGORY_4_ACCIDENTAL                  0x00000049
#define             UNICODE_CATEGORY_4_ANALYTIC                    0x0000004a
#define             UNICODE_CATEGORY_4_ARTICULATION                0x0000004b
#define             UNICODE_CATEGORY_4_AUGMENTATION_DOT            0x0000004c
#define             UNICODE_CATEGORY_4_BAR                         0x0000004d
#define             UNICODE_CATEGORY_4_BEAM_SLUR                   0x0000004e
#define             UNICODE_CATEGORY_4_CLEF                        0x0000004f
#define             UNICODE_CATEGORY_4_CODA                        0x00000050
#define             UNICODE_CATEGORY_4_DYNAMIC                     0x00000051
#define             UNICODE_CATEGORY_4_FIGURE_REPETITION           0x00000052
#define             UNICODE_CATEGORY_4_FLAG                        0x00000053
#define             UNICODE_CATEGORY_4_HOLD_OR_PAUSE               0x00000054
#define             UNICODE_CATEGORY_4_INSTRUMENTATION             0x00000055
#define             UNICODE_CATEGORY_4_NOTE                        0x00000056
#define             UNICODE_CATEGORY_4_NOTEHEAD                    0x00000057
#define             UNICODE_CATEGORY_4_OCTAVE                      0x00000058
#define             UNICODE_CATEGORY_4_ORNAMENT                    0x00000059
#define             UNICODE_CATEGORY_4_PEDAL                       0x0000005a
/* #define             UNICODE_CATEGORY_4_REST                     0x00000048 */
#define             UNICODE_CATEGORY_4_STAFF_BRACKET               0x0000005b
#define             UNICODE_CATEGORY_4_STAVE                       0x0000005c
#define             UNICODE_CATEGORY_4_STEM                        0x0000005d
#define             UNICODE_CATEGORY_4_TABLATURE                   0x0000005e
#define             UNICODE_CATEGORY_4_TIME_SIGNATURE              0x0000005f
#define             UNICODE_CATEGORY_4_TREMOLO                     0x00000060
#define     UNICODE_CATEGORY_2_MUSICAL                             0x007c0000
#define         UNICODE_CATEGORY_3_BALINESE                        0x00005500
/* #define             UNICODE_CATEGORY_4_NOTE                     0x00000056 */
/* #define     UNICODE_CATEGORY_2_NUMBER                           0x00090000 */
/* #define         UNICODE_CATEGORY_3_CIRCLED                      0x00004100 */
#define         UNICODE_CATEGORY_3_COUNTING_ROD_UNIT               0x00005600
/* #define         UNICODE_CATEGORY_3_PARENTHESIZED                0x00004200 */
#define     UNICODE_CATEGORY_2_OCR                                 0x007d0000
#define     UNICODE_CATEGORY_2_OFFICE                              0x007e0000
#define     UNICODE_CATEGORY_2_PERSON                              0x007f0000
#define         UNICODE_CATEGORY_3_OCCUPATION                      0x00005700
#define     UNICODE_CATEGORY_2_PERSONAL_CARE                       0x00800000
#define     UNICODE_CATEGORY_2_PLANT                               0x00810000
#define     UNICODE_CATEGORY_2_POETIC                              0x00820000
#define     UNICODE_CATEGORY_2_RECYCLING                           0x00830000
#define     UNICODE_CATEGORY_2_RELIGIOUS                           0x00840000
#define     UNICODE_CATEGORY_2_REPLACEMENT                         0x00850000
#define     UNICODE_CATEGORY_2_ROMANCE                             0x00860000
#define     UNICODE_CATEGORY_2_SCHOOL                              0x00870000
#define     UNICODE_CATEGORY_2_SIGNAGE                             0x00880000
#define     UNICODE_CATEGORY_2_SPORT                               0x00890000
#define     UNICODE_CATEGORY_2_SPORTS                              0x008a0000
#define     UNICODE_CATEGORY_2_STARLIKE                            0x008b0000
#define     UNICODE_CATEGORY_2_SYLLABLE                            0x008c0000
/* #define         UNICODE_CATEGORY_3_CIRCLED                      0x00004100 */
/* #define         UNICODE_CATEGORY_3_PARENTHESIZED                0x00004200 */
/* #define         UNICODE_CATEGORY_3_SQUARED                      0x00004300 */
#define     UNICODE_CATEGORY_2_TECHNICAL                           0x008d0000
#define         UNICODE_CATEGORY_3_APL                             0x00005800
#define         UNICODE_CATEGORY_3_CHEMISTRY                       0x00005900
#define         UNICODE_CATEGORY_3_CROP                            0x00005a00
#define         UNICODE_CATEGORY_3_DENTISTRY                       0x00005b00
#define         UNICODE_CATEGORY_3_DRAFTING                        0x00005c00
#define         UNICODE_CATEGORY_3_INTERFACE                       0x00005d00
#define             UNICODE_CATEGORY_4_ARROW                       0x00000061
#define             UNICODE_CATEGORY_4_INPUT_STATUS                0x00000062
#define         UNICODE_CATEGORY_3_KEYBOARD                        0x00005e00
#define         UNICODE_CATEGORY_3_QUINE_CORNER                    0x00005f00
#define     UNICODE_CATEGORY_2_TELEGRAPHIC                         0x008e0000
#define     UNICODE_CATEGORY_2_TETRAGRAM                           0x008f0000
#define     UNICODE_CATEGORY_2_TOOL                                0x00900000
#define     UNICODE_CATEGORY_2_TRAFFIC_SIGN                        0x00910000
#define     UNICODE_CATEGORY_2_TRANSLITERATION                     0x00920000
#define     UNICODE_CATEGORY_2_TRIGRAM                             0x00930000
/* #define         UNICODE_CATEGORY_3_YIJING                       0x00002900 */
#define     UNICODE_CATEGORY_2_VEHICLE                             0x00940000
#define     UNICODE_CATEGORY_2_WARNING_SIGN                        0x00950000
#define     UNICODE_CATEGORY_2_WEATHER                             0x00960000
#define     UNICODE_CATEGORY_2_WORD                                0x00970000
/* #define         UNICODE_CATEGORY_3_CIRCLED                      0x00004100 */
/* #define         UNICODE_CATEGORY_3_PARENTHESIZED                0x00004200 */
/* #define         UNICODE_CATEGORY_3_SQUARED                      0x00004300 */
#define     UNICODE_CATEGORY_2_ZODIAC                              0x00980000
#define UNICODE_CATEGORY_1_VIRAMA                                  0x0f000000
#define UNICODE_CATEGORY_1_VOWEL                                   0x10000000
#define UNICODE_CATEGORY_1_WORD                                    0x11000000
/* #define     UNICODE_CATEGORY_2_LIGATURE                         0x003e0000 */
